=== modified file 'olive/backend/commit.py'
--- olive/backend/commit.py	2006-07-21 18:18:20 +0000
+++ olive/backend/commit.py	2006-09-04 23:33:13 +0000
@@ -19,16 +19,13 @@
 import codecs
 
 import bzrlib
-import bzrlib.errors as errors
+from bzrlib.errors import NoSuchFile
 
-from errors import (EmptyMessageError, NoMessageNoFileError,
-                    NoChangesToCommitError, ConflictsInTreeError,
-                    StrictCommitError, BoundBranchOutOfDate,
-                    LocalRequiresBoundBranch, NotBranchError, NonExistingParent,
+from errors import ( LocalRequiresBoundBranch, NotBranchError, NonExistingParent,
                     PathPrefixNotCreated, NoLocationKnown,
                     DivergedBranchesError)
 
-def commit(selected_list, message=None, file=None, unchanged=False,
+def commit(selected_list, message=None, unchanged=False,
            strict=False, local=False):
     """ Command to commit changes into the branch.
     
@@ -47,39 +44,19 @@
     from bzrlib.builtins import tree_files
     from bzrlib.commit import NullCommitReporter
 
-    try:
-        tree, selected_list = tree_files(selected_list)
-    except errors.NotBranchError:
-        raise NotBranchError
+    tree, selected_list = tree_files(selected_list)
     
     if local and not tree.branch.get_bound_location():
         raise LocalRequiresBoundBranch
-    if message is None and not file:
-        if message is None:
-            raise NoMessageNoFileError
-    elif message and file:
-        raise NoMessageNoFileError
-
-    if file:
-        message = codecs.open(file, 'rt', bzrlib.user_encoding).read()
-
-    if message == "":
-        raise EmptyMessageError
-
+
+    assert message is not None and len(message) > 0
+
+    # FIXME: This should be a GtkCommitReporter!
     reporter = NullCommitReporter()
 
-    try:
-        tree.commit(message, specific_files=selected_list,
+    tree.commit(message, specific_files=selected_list,
                     allow_pointless=unchanged, strict=strict, local=local,
                     reporter=reporter)
-    except errors.PointlessCommit:
-        raise NoChangesToCommitError
-    except errors.ConflictsInTree:
-        raise ConflictsInTreeError
-    except errors.StrictCommitFailed:
-        raise StrictCommitError
-    except errors.BoundBranchOutOfDate, e:
-        raise BoundBranchOutOfDate(str(e))
 
 def push(branch, location=None, remember=False, overwrite=False,
          create_prefix=False):
@@ -100,12 +77,7 @@
     from bzrlib.branch import Branch
     from bzrlib.transport import get_transport
         
-    try:
-        br_from = Branch.open_containing(branch)[0]
-    except errors.NotBranchError:
-        raise NotBranchError(branch)
-    except:
-        raise
+    br_from = Branch.open_containing(branch)[0]
     
     stored_loc = br_from.get_push_location()
     if location is None:
@@ -125,14 +97,14 @@
     try:
         dir_to = bzrlib.bzrdir.BzrDir.open(location_url)
         br_to = dir_to.open_branch()
-    except errors.NotBranchError:
+    except NotBranchError:
         # create a branch.
         transport = transport.clone('..')
         if not create_prefix:
             try:
                 relurl = transport.relpath(location_url)
                 transport.mkdir(relurl)
-            except errors.NoSuchFile:
+            except NoSuchFile:
                 raise NonExistingParent(location)
         else:
             current = transport.base
@@ -142,7 +114,7 @@
                     transport, relpath = needed[-1]
                     transport.mkdir(relpath)
                     needed.pop()
-                except errors.NoSuchFile:
+                except NoSuchFile:
                     new_transport = transport.clone('..')
                     needed.append((new_transport,
                                    new_transport.relpath(transport.base)))
@@ -157,16 +129,16 @@
         try:
             try:
                 tree_to = dir_to.open_workingtree()
-            except errors.NotLocalUrl:
+            except NotLocalUrl:
                 # FIXME - what to do here? how should we warn the user?
                 #warning('This transport does not update the working '
                 #        'tree of: %s' % (br_to.base,))
                 count = br_to.pull(br_from, overwrite)
-            except errors.NoWorkingTree:
+            except NoWorkingTree:
                 count = br_to.pull(br_from, overwrite)
             else:
                 count = tree_to.pull(br_from, overwrite)
-        except errors.DivergedBranches:
+        except DivergedBranches:
             raise DivergedBranchesError
     
     return count

=== removed file 'olive/backend/errors.py'
--- olive/backend/errors.py	2006-09-02 14:27:00 +0000
+++ olive/backend/errors.py	1970-01-01 00:00:00 +0000
@@ -1,231 +0,0 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
-# Some parts of the code are:
-# Copyright (C) 2005, 2006 by Canonical Ltd
-
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-class OliveError(Exception):
-    """ Parent class for Olive exceptions/errors """
-    pass
-
-class AlreadyBranchError(OliveError):
-    """ The specified directory is already a branch
-    
-    May occur in:
-        init.init()
-    """
-
-class BoundBranchOutOfDate(OliveError):
-    """ Occurs if the bound branch is out of date
-    
-    May occur in:
-        commit.commit()
-    """
-
-class BranchExistsWithoutWorkingTree(OliveError):
-    """ The specified directory is a branch, however it doesn't contain a working tree
-    
-    May occur in:
-        init.init()
-    """
-
-class ConflictsInTreeError(OliveError):
-    """ Occurs if non-resolved conflicts remained in the tree
-    
-    May occur in:
-        commit.commit()
-    """
-
-class ConnectionError(OliveError):
-    """ Occurs if cannot connect to remote host
-    
-    May occur in:
-        update.missing()
-    """
-
-class DifferentBranchesError(OliveError):
-    """ Occurs if the specified files are in different branches
-    
-    May occur in:
-        info.diff()
-    """
-
-class DirectoryAlreadyExists(OliveError):
-    """ The specified directory already exists
-    
-    May occur in:
-        fileops.mkdir()
-    """
-
-class DivergedBranchesError(OliveError):
-    """ The branches have been diverged
-    
-    May occur in:
-        commit.push()
-    """
-
-class EmptyMessageError(OliveError):
-    """ Occurs if no commit message specified
-    
-    May occur in:
-        commit.commit()
-    """
-
-class LocalRequiresBoundBranch(OliveError):
-    """ Occurs when the local branch needs a bound branch
-    
-    May occur in:
-        commit.commit()
-    """
-
-class MissingArgumentError(OliveError):
-    """ Occurs when not enough parameters are given.
-    
-    May occur in:
-        fileops.move()
-    """
-
-class MultipleMoveError(OliveError):
-    """ Occurs when moving/renaming more than 2 files, but the last argument is not a directory
-    
-    May occur in:
-        fileops.move()
-    """
-
-class NoChangesToCommitError(OliveError):
-    """ Occurs if there are no changes to commit
-    
-    May occur in:
-        commit.commit()
-    """
-
-class NoFilesSpecified(OliveError):
-    """ No files were specified as an argument to a function
-    
-    May occur in:
-        fileops.remove()
-    """
-
-class NoLocationKnown(OliveError):
-    """ No location known or specified
-    
-    May occur in:
-        commit.push()
-        init.pull()
-    """
-
-class NoMatchingFiles(OliveError):
-    """ No files found which could match the criteria
-    
-    May occur in:
-        fileops.remove()
-    """
-
-class NoMessageNoFileError(OliveError):
-    """ No message and no file given (for commit)
-    
-    May occur in:
-        commit.commit()
-    """
-
-class NonExistingParent(OliveError):
-    """ Parent directory doesn't exist
-    
-    May occur in:
-        init.branch()
-        init.checkout()
-        commit.push()
-    """
-
-class NonExistingRevision(OliveError):
-    """ The specified revision doesn't exist in the branch
-    
-    May occur in:
-        init.branch()
-    """
-
-class NonExistingSource(OliveError):
-    """ The source provided doesn't exist
-    
-    May occur in:
-        init.branch()
-        fileops.rename()
-    """
-
-class NotBranchError(OliveError):
-    """ Specified directory is not a branch
-    
-    May occur in:
-        commit.commit()
-        init.branch()
-        init.checkout()
-    """
-
-class NotSameBranchError(OliveError):
-    """ The specified files are not in the same branch
-    
-    May occur in:
-        fileops.move()
-    """
-
-class NotVersionedError(OliveError):
-    """ Occurs if the specified file/directory is not in the branch
-    
-    May occur in:
-        fileops.remove()
-    """
-
-class PathPrefixNotCreated(OliveError):
-    """ The path prefix couldn't be created
-    
-    May occur in:
-        commit.push()
-    """
-
-class PermissionDenied(OliveError):
-    """ Permission denied.
-    
-    May occur in:
-        fileops.status()
-    """
-
-class PrefixFormatError(OliveError):
-    """ Occurs if the prefix is badly formatted
-    
-    May occur in:
-        info.diff()
-    """
-
-class RevisionValueError(OliveError):
-    """ Invalid revision value provided
-    
-    May occur in:
-        info.log()
-    """
-
-class StrictCommitError(OliveError):
-    """ Occurs if strict commit fails
-    
-    May occur in:
-        commit.commit()
-    """
-
-class TargetAlreadyExists(OliveError):
-    """ Target directory already exists
-    
-    May occur in:
-        init.branch()
-        init.checkout()
-    """

=== modified file 'olive/backend/fileops.py'
--- olive/backend/fileops.py	2006-08-20 14:01:33 +0000
+++ olive/backend/fileops.py	2006-09-04 23:33:13 +0000
@@ -18,12 +18,33 @@
 
 import os
 
-import bzrlib.errors as errors
-
-from errors import (DirectoryAlreadyExists, MissingArgumentError,
-                    MultipleMoveError, NoFilesSpecified, NoMatchingFiles,
-                    NonExistingSource, NotBranchError, NotSameBranchError,
-                    NotVersionedError, PermissionDenied)
+from bzrlib.errors import (BzrError, NotBranchError, NotVersionedError, 
+                           PermissionDenied)
+
+
+class DirectoryAlreadyExists(BzrError):
+    """ The specified directory already exists
+    
+    May occur in:
+        fileops.mkdir()
+    """
+
+
+class MultipleMoveError(BzrError):
+    """ Occurs when moving/renaming more than 2 files, but the last argument is not a directory
+    
+    May occur in:
+        fileops.move()
+    """
+
+
+class NoMatchingFiles(BzrError):
+    """ No files found which could match the criteria
+    
+    May occur in:
+        fileops.remove()
+    """
+
 
 def add(file_list, recursive=False):
     """ Add listed files to the branch. 
@@ -36,12 +57,7 @@
     """
     import bzrlib.add
     
-    try:
-        added, ignored = bzrlib.add.smart_add(file_list, recursive)
-    except errors.NotBranchError:
-        raise NotBranchError
-    except:
-        raise
+    added, ignored = bzrlib.add.smart_add(file_list, recursive)
     
     match_len = 0
     for glob, paths in ignored.items():
@@ -62,12 +78,8 @@
         if e.errno == 17:
             raise DirectoryAlreadyExists(directory)
     else:
-        try:
-            wt, dd = WorkingTree.open_containing(directory)
-        except errors.NotBranchError:
-            raise NotBranchError
-        else:
-            wt.add([dd])
+        wt, dd = WorkingTree.open_containing(directory)
+        wt.add([dd])
 
 def move(names_list):
     """ Move or rename given files.
@@ -76,16 +88,7 @@
     """
     from bzrlib.builtins import tree_files
     
-    if len(names_list) < 2:
-        raise MissingArgumentError
-    
-    try:
-        tree, rel_names = tree_files(names_list)
-    except errors.NotBranchError:
-        raise NotBranchError
-    except errors.BzrCommandError:
-        # not the same branch presumably
-        raise NotSameBranchError
+    tree, rel_names = tree_files(names_list)
         
     if os.path.isdir(names_list[-1]):
         # move into existing directory
@@ -96,6 +99,7 @@
             raise MultipleMoveError
         tree.rename_one(rel_names[0], rel_names[1])
 
+
 def remove(file_list, new=False):
     """ Make selected files unversioned.
     
@@ -106,17 +110,9 @@
     import bzrlib
     from bzrlib.builtins import tree_files
     
-    try:
-        tree, file_list = tree_files(file_list)
-    except errors.NotBranchError:
-        raise NotBranchError
-    except:
-        raise
+    tree, file_list = tree_files(file_list)
     
-    if new is False:
-        if file_list is None:
-            raise NoFilesSpecified
-    else:
+    if new:
         from bzrlib.delta import compare_trees
         if (bzrlib.version_info[0] == 0) and (bzrlib.version_info[1] < 9):
             added = [compare_trees(tree.basis_tree(), tree,
@@ -128,10 +124,8 @@
         if len(file_list) == 0:
             raise NoMatchingFiles
     
-    try:
-        tree.remove(file_list)
-    except errors.NotVersionedError:
-        raise NotVersionedError
+    tree.remove(file_list)
+
 
 def rename(source, target):
     """ Rename a versioned file
@@ -140,9 +134,6 @@
     
     :param target: full path to the new file
     """
-    if os.access(source, os.F_OK) is not True:
-        raise NonExistingSource(source)
-    
     move([source, target])
 
 def status(filename):
@@ -158,10 +149,8 @@
     
     try:
         tree1 = WorkingTree.open_containing(filename)[0]
-    except errors.NotBranchError:
+    except NotBranchError:
         return 'unknown'
-    except errors.PermissionDenied:
-        raise PermissionDenied(filename)
     
     branch = tree1.branch
     tree2 = tree1.branch.repository.revision_tree(branch.last_revision())

=== modified file 'olive/backend/info.py'
--- olive/backend/info.py	2006-08-20 14:01:33 +0000
+++ olive/backend/info.py	2006-09-04 23:33:13 +0000
@@ -22,8 +22,31 @@
 from bzrlib.branch import Branch
 from bzrlib.workingtree import WorkingTree
 
-from errors import (DifferentBranchesError, NotBranchError, PermissionDenied,
-                    PrefixFormatError, RevisionValueError)
+from bzrlib.errors import (NotBranchError, PermissionDenied, BzrError)
+
+class DifferentBranchesError(BzrError):
+    """ Occurs if the specified files are in different branches
+    
+    May occur in:
+        info.diff()
+    """
+
+
+class PrefixFormatError(BzrError):
+    """ Occurs if the prefix is badly formatted
+    
+    May occur in:
+        info.diff()
+    """
+
+
+class RevisionValueError(BzrError):
+    """ Invalid revision value provided
+    
+    May occur in:
+        info.log()
+    """
+
 
 def diff(revision=None, file_list=None, diff_options=None, prefix=None):
     """ Save the diff into a temporary file.

=== modified file 'olive/backend/init.py'
--- olive/backend/init.py	2006-07-21 18:18:20 +0000
+++ olive/backend/init.py	2006-09-04 23:33:13 +0000
@@ -21,13 +21,10 @@
 
 import bzrlib
 import bzrlib.bzrdir as bzrdir
-import bzrlib.errors as errors
 
 from bzrlib.branch import Branch
 
-from errors import (AlreadyBranchError, BranchExistsWithoutWorkingTree,
-                    NonExistingParent, NonExistingRevision,
-                    NonExistingSource, NotBranchError, TargetAlreadyExists)
+from bzrlib.errors import (AlreadyBranchError, BranchExistsWithoutWorkingTree)
 
 def branch(from_location, to_location, revision=None):
     """ Create a branch from a local/remote location.
@@ -42,15 +39,7 @@
     """
     from bzrlib.transport import get_transport
 
-    try:
-        br_from = Branch.open(from_location)
-    except OSError, e:
-        if e.errno == errno.ENOENT:
-            raise NonExistingSource(from_location)
-        else:
-            raise
-    except errors.NotBranchError:
-        raise NotBranchError(from_location)
+    br_from = Branch.open(from_location)
 
     br_from.lock_read()
 
@@ -65,19 +54,14 @@
         name = None
         to_transport = get_transport(to_location)
 
-        try:
-            to_transport.mkdir('.')
-        except errors.FileExists:
-            raise TargetAlreadyExists(to_location)
-        except errors.NoSuchFile:
-            raise NonExistingParent(to_location)
+        to_transport.mkdir('.')
 
         try:
             dir = br_from.bzrdir.sprout(to_transport.base, revision_id, basis_dir)
             branch = dir.open_branch()
-        except errors.NoSuchRevision:
+        except NoSuchRevision:
             to_transport.delete_tree('.')
-            raise NonExistingRevision(from_location, revision[0])
+            raise
 
         if name:
             branch.control_files.put_utf8('branch-name', name)
@@ -97,10 +81,7 @@
     
     :param lightweight: perform a lightweight checkout (be aware!)
     """
-    try:
-        source = Branch.open(branch_location)
-    except errors.NotBranchError:
-        raise NotBranchError(branch_location)
+    source = Branch.open(branch_location)
     
     if revision is not None:
         revision_id = source.get_rev_id(revision)
@@ -114,21 +95,13 @@
         bzrlib.osutils.abspath(branch_location)):
         try:
             source.bzrdir.open_workingtree()
-        except errors.NoWorkingTree:
+        except NoWorkingTree:
             source.bzrdir.create_workingtree()
             return
 
     to_location = to_location + '/' + os.path.basename(branch_location.rstrip("/\\"))
     
-    try:
-        os.mkdir(to_location)
-    except OSError, e:
-        if e.errno == errno.EEXIST:
-            raise TargetAlreadyExists(to_location)
-        if e.errno == errno.ENOENT:
-            raise NonExistingParent(to_location)
-        else:
-            raise
+    os.mkdir(to_location)
 
     old_format = bzrlib.bzrdir.BzrDirFormat.get_default_format()
     bzrlib.bzrdir.BzrDirFormat.set_default_format(bzrdir.BzrDirMetaFormat1())
@@ -164,7 +137,7 @@
  
     try:
         existing_bzrdir = bzrdir.BzrDir.open(location)
-    except errors.NotBranchError:
+    except NotBranchError:
         bzrdir.BzrDir.create_branch_convenience(location, format=format)
     else:
         if existing_bzrdir.has_branch():

=== modified file 'olive/backend/update.py'
--- olive/backend/update.py	2006-09-02 14:27:00 +0000
+++ olive/backend/update.py	2006-09-04 23:33:13 +0000
@@ -16,11 +16,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import bzrlib.errors as errors
-
 from bzrlib.workingtree import WorkingTree
 
-from errors import ConnectionError, NoLocationKnown, NotBranchError
+from bzrlib.errors import NoLocationKnown
 
 def missing(branch, other_branch=None, reverse=False):
     """ Get the number of missing or extra revisions of local branch.
@@ -36,12 +34,7 @@
     import bzrlib
     from bzrlib.missing import find_unmerged
     
-    try:
-        local_branch = bzrlib.branch.Branch.open_containing(branch)[0]
-    except errors.NotBranchError:
-        raise NotBranchError(branch)
-    except:
-        raise
+    local_branch = bzrlib.branch.Branch.open_containing(branch)[0]
     
     parent = local_branch.get_parent()
     if other_branch is None:
@@ -49,14 +42,7 @@
         if other_branch is None:
             raise NoLocationKnown
     
-    try:
-        remote_branch = bzrlib.branch.Branch.open(other_branch)
-    except errors.NotBranchError:
-        raise NotBranchError(other_branch)
-    except errors.ConnectionError:
-        raise ConnectionError(other_branch)
-    except:
-        raise
+    remote_branch = bzrlib.branch.Branch.open(other_branch)
     
     if remote_branch.base == local_branch.base:
         remote_branch = local_branch
@@ -127,20 +113,15 @@
     try:
         tree_to = WorkingTree.open_containing(branch)[0]
         branch_to = tree_to.branch
-    except errors.NoWorkingTree:
+    except NoWorkingTree:
         tree_to = None
-        try:
-            branch_to = Branch.open_containing(branch)[0]
-        except errors.NotBranchError:
-            raise NotBranchError(location)
-    except errors.NotBranchError:
-        raise NotBranchError(location)
+        branch_to = Branch.open_containing(branch)[0]
 
     reader = None
     if location is not None and not nobundle:
         try:
             reader = read_bundle_from_url(location)
-        except errors.NotABundle:
+        except NotABundle:
             pass # Continue on considering this url a Branch
 
     stored_loc = branch_to.get_parent()

=== modified file 'olive/frontend/gtk/__init__.py'
--- olive/frontend/gtk/__init__.py	2006-09-04 01:02:20 +0000
+++ olive/frontend/gtk/__init__.py	2006-09-04 23:33:13 +0000
@@ -33,7 +33,7 @@
 
 from handler import OliveHandler
 from olive.backend.info import is_branch
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 
 # Olive GTK UI version
 __version__ = '0.10.0'

=== modified file 'olive/frontend/gtk/add.py'
--- olive/frontend/gtk/add.py	2006-09-02 13:51:41 +0000
+++ olive/frontend/gtk/add.py	2006-09-04 23:33:13 +0000
@@ -27,7 +27,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.fileops as fileops
 
 class OliveAdd:

=== modified file 'olive/frontend/gtk/branch.py'
--- olive/frontend/gtk/branch.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/branch.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
     sys.exit(1)
 
 import olive.backend.init as init
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 
 class OliveBranch:
     """ Display branch dialog and perform the needed operations. """

=== modified file 'olive/frontend/gtk/checkout.py'
--- olive/frontend/gtk/checkout.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/checkout.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
     sys.exit(1)
 
 import olive.backend.init as init
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 
 class OliveCheckout:
     """ Display checkout dialog and perform the needed operations. """

=== modified file 'olive/frontend/gtk/handler.py'
--- olive/frontend/gtk/handler.py	2006-09-02 14:27:00 +0000
+++ olive/frontend/gtk/handler.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
     sys.exit(1)
 
 from olive.backend.info import is_branch
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 
 from dialog import OliveDialog
 from menu import OliveMenu

=== modified file 'olive/frontend/gtk/info.py'
--- olive/frontend/gtk/info.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/info.py	2006-09-04 23:33:13 +0000
@@ -29,7 +29,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.info as info
 
 class OliveInfo:

=== modified file 'olive/frontend/gtk/menu.py'
--- olive/frontend/gtk/menu.py	2006-08-20 16:41:46 +0000
+++ olive/frontend/gtk/menu.py	2006-09-04 23:33:13 +0000
@@ -29,7 +29,7 @@
     sys.exit(1)
 
 import olive.backend.fileops as fileops
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 
 class OliveMenu:
     """ This class is responsible for building the context menus. """

=== modified file 'olive/frontend/gtk/mkdir.py'
--- olive/frontend/gtk/mkdir.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/mkdir.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.fileops as fileops
 
 class OliveMkdir:

=== modified file 'olive/frontend/gtk/move.py'
--- olive/frontend/gtk/move.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/move.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.fileops as fileops
 
 class OliveMove:

=== modified file 'olive/frontend/gtk/push.py'
--- olive/frontend/gtk/push.py	2006-08-21 00:06:30 +0000
+++ olive/frontend/gtk/push.py	2006-09-04 23:33:13 +0000
@@ -29,7 +29,7 @@
     sys.exit(1)
 
 import olive.backend.commit as commit
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.info as info
 
 class OlivePush:

=== modified file 'olive/frontend/gtk/remove.py'
--- olive/frontend/gtk/remove.py	2006-09-02 13:51:41 +0000
+++ olive/frontend/gtk/remove.py	2006-09-04 23:33:13 +0000
@@ -27,7 +27,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.fileops as fileops
 
 class OliveRemove:

=== modified file 'olive/frontend/gtk/rename.py'
--- olive/frontend/gtk/rename.py	2006-08-20 13:02:35 +0000
+++ olive/frontend/gtk/rename.py	2006-09-04 23:33:13 +0000
@@ -28,7 +28,7 @@
 except:
     sys.exit(1)
 
-import olive.backend.errors as errors
+import bzrlib.errors as errors
 import olive.backend.fileops as fileops
 
 class OliveRename:

